# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class BuilderTagsType(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'values': 'list[str]',
        'aggregate_function_type': 'BuilderAggregateFunctionType'
    }

    attribute_map = {
        'key': 'key',
        'values': 'values',
        'aggregate_function_type': 'aggregateFunctionType'
    }

    def __init__(self, key=None, values=None, aggregate_function_type=None):  # noqa: E501,D401,D403
        """BuilderTagsType - a model defined in OpenAPI."""  # noqa: E501
        self._key = None
        self._values = None
        self._aggregate_function_type = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if values is not None:
            self.values = values
        if aggregate_function_type is not None:
            self.aggregate_function_type = aggregate_function_type

    @property
    def key(self):
        """Get the key of this BuilderTagsType.

        :return: The key of this BuilderTagsType.
        :rtype: str
        """  # noqa: E501
        return self._key

    @key.setter
    def key(self, key):
        """Set the key of this BuilderTagsType.

        :param key: The key of this BuilderTagsType.
        :type: str
        """  # noqa: E501
        self._key = key

    @property
    def values(self):
        """Get the values of this BuilderTagsType.

        :return: The values of this BuilderTagsType.
        :rtype: list[str]
        """  # noqa: E501
        return self._values

    @values.setter
    def values(self, values):
        """Set the values of this BuilderTagsType.

        :param values: The values of this BuilderTagsType.
        :type: list[str]
        """  # noqa: E501
        self._values = values

    @property
    def aggregate_function_type(self):
        """Get the aggregate_function_type of this BuilderTagsType.

        :return: The aggregate_function_type of this BuilderTagsType.
        :rtype: BuilderAggregateFunctionType
        """  # noqa: E501
        return self._aggregate_function_type

    @aggregate_function_type.setter
    def aggregate_function_type(self, aggregate_function_type):
        """Set the aggregate_function_type of this BuilderTagsType.

        :param aggregate_function_type: The aggregate_function_type of this BuilderTagsType.
        :type: BuilderAggregateFunctionType
        """  # noqa: E501
        self._aggregate_function_type = aggregate_function_type

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, BuilderTagsType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other
